@@ -1,6 +1,6 @@
 
 import numpy as np
-from flagsercount_pybind import run_flagser_count
+from .modules.flagsercount_pybind import run_flagser_count
 
 def flagser_count(adjacency_matrix,max_simplices=False,containment=False,
                   return_simplices=False, print='',threads=8,transpose=False,out='',binary='',max_dim=-1,
